@@ -21,7 +21,9 @@ pub enum Error {
 	#[error("title ID {0} not found")]
 	NotFound(u32),
 	#[error("cache failure")]
-	Cache(#[from] indexkv::Error<u32>)
+	Cache(#[from] indexkv::Error<u32>),
+	#[error("invalid genre {0}")]
+	InvalidGenre(String)
 }
 
 impl From<StreamError<Error, u32>> for Error {
